﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using EnvDTE;
using TCatSysManagerLib;

namespace TwinCAT_Interface_Demo1
{
    public partial class Form1 : Form
    {
        private EnvDTE.DTE dte;                // Visual Studio DTE 对象
        private ITcSysManager sysManager;      // TwinCAT 系统管理器对象
        private Type t;                        // 用于存储所选的 Visual Studio 版本的类型
        private string solnPath;               // 存储解决方案路径

        public Form1()
        {
            InitializeComponent();
            comboBox1.Items.Add("TcXaeShell");
            comboBox1.Items.Add("Visual Studio 2015");
            comboBox1.Items.Add("Visual Studio 2017");
            comboBox1.Items.Add("Visual Studio 2019");
        }

        private void button1_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(comboBox1.Text) || string.IsNullOrEmpty(textBox1.Text))
            {
                // 如果选择框或文本框为空，则提示警告窗口
                MessageBox.Show("Please choose the correct path and Visual Studio Version!", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            try
            {
                // 创建所选的 Visual Studio 版本的 DTE 对象
                dte = (EnvDTE.DTE)System.Activator.CreateInstance(t);
                dte.MainWindow.Visible = true;

                // 打开指定路径下的解决方案
                dte.Solution.Open(solnPath);
            }
            catch (Exception ex)
            {
                // 捕获异常，并根据用户选择处理错误
                DialogResult result = MessageBox.Show("Solution " + solnPath + " cannot be opened. Invalid Path or Visual Studio Version!", "Error", MessageBoxButtons.YesNo, MessageBoxIcon.Error);

                if (result == DialogResult.Yes)
                {
                    // 选择"是"，可以进行其他处理
                }
                else if (result == DialogResult.No)
                {
                    // 选择"否"，显示再见信息，并退出应用程序
                    MessageBox.Show("It seems that you cannot realize your problem. It is time to say goodbye!","Message");
                    Application.Exit();
                }
            }
        }

        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            // 根据选择的版本设置相应的 DTE 类型
            string selectedOption = comboBox1.SelectedItem.ToString();

            switch (selectedOption)
            {
                case "TcXaeShell":
                    t = System.Type.GetTypeFromProgID("TcXaeShell.DTE.15.0");
                    break;

                case "Visual Studio 2015":
                    t = System.Type.GetTypeFromProgID("VisualStudio.DTE.14.0");
                    break;

                case "Visual Studio 2017":
                    t = System.Type.GetTypeFromProgID("VisualStudio.DTE.15.0");
                    break;

                case "Visual Studio 2019":
                    t = System.Type.GetTypeFromProgID("VisualStudio.DTE.16.0");
                    break;

                default:
                    t = System.Type.GetTypeFromProgID("TcXaeShell.DTE.15.0");
                    break;
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(comboBox1.Text) || string.IsNullOrEmpty(textBox1.Text))
            {
                // 如果选择框或文本框为空，则提示警告窗口
                MessageBox.Show("Please choose the correct path and Visual Studio Version!", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            try
            {
                // 获取解决方案中的第一个项目，并获取其 TwinCAT 系统管理器对象
                EnvDTE.Solution sol = dte.Solution;
                EnvDTE.Project pro = sol.Projects.Item(1);
                sysManager = pro.Object;

                // 激活配置并启动或重新启动 TwinCAT
                sysManager.ActivateConfiguration();
                sysManager.StartRestartTwinCAT();
            }
            catch (Exception ex)
            {
                // 捕获异常，并显示错误信息
                MessageBox.Show(ex.Message, "Error");
            }
        }

        private void textBox1_TextChanged(object sender, EventArgs e)
        {
            // 更新解决方案路径
            solnPath = @textBox1.Text;
        }
    }
}
